<?php 
$translations = array(
	'General_Locale' => 'es_ES.UTF-8',
	'General_TranslatorName' => 'Marcos Alberto Sanmartín Pereira, Alejandro Escario',
	'General_TranslatorEmail' => 'ahriman89@gmail.com, escarion@gmail.com',
	'General_EnglishLanguageName' => 'Spanish',
	'General_OriginalLanguageName' => 'Español',
	'General_HelloUser'	=> '¡Hola, %s!',
	'General_OpenSourceWebAnalytics' => 'Análisis Web de Código Abierto',
	'General_YourDashboard' => 'Tu Panel',
	'General_API' => 'API',
	'General_Widgets' => 'Widgets',
	'General_Settings'	=> 'Configuración',
	'General_GiveUsYourFeedback' => '¡Envíanos comentarios!',
	'General_Unknown' => 'Desconocido',
	'General_Required' => '%s necesario',
	'General_Error' => 'Error',
	'General_Warning' => 'Advertencia',
	'General_BackToHomepage' => 'Voler a la página de inicio Piwik',
	'General_Yes' => 'Si',
	'General_No' => 'No',
	'General_Delete' => 'Borrar',
	'General_Edit' => 'Editar',
	'General_Ok' => 'Aceptar',
	'General_Close' => 'Cerrar',
	'General_Logout' => 'Desconectarse',
	'General_Done' => '¡Hecho',
	'General_LoadingData' => 'Cargando datos...',
	'General_Loading' => 'Cargando...',
	'General_ErrorRequest' => 'Oops&hellip; problema durante la petición, por favor inténtelo de nuevo.',
	'General_Next' => 'Siguiente',
	'General_Previous' => 'Anterior',
	'General_Search' => 'Buscar',
	'General_Others' => 'Otros',
	'General_Table' => 'Tabla',
	'General_Piechart' => 'Gráfica circular',
	'General_TagCloud' => 'Nube de Etiquetas',
	'General_VBarGraph' => 'Gráfica de barras verticales',
	'General_Export' => 'Exportar',
	'General_ExportAsImage' => 'Exportar como imagen',
	'General_SaveImageOnYourComputer' => 'Para guardar la imagen en su ordenador, haga clic derecho en la imagen y seleccione "Guardar imagen como..."',
	'General_Refresh' => 'Actualizar la página',
	'General_Visitors' => 'Visitantes',
	'General_ColumnNbUniqVisitors' => 'Visitantes únicos',
	'General_ColumnNbVisits' => 'Visitas',
	'General_ColumnNbActions' => 'Acciones',
	'General_ColumnMaxActions' => 'acciones máximas en una visita',
	'General_ColumnSumVisitLength' => 'Tiempo total de los visitantes en el sitio (en segundos)',
	'General_ColumnLabel' => 'Etiqueta',
	'General_ColumnActionsPerVisit' => 'Acciones por visita',
	'General_ColumnAvgTimeOnSite' => 'Promedio de tiempo en el sitio',
	'General_ColumnBounceRate' => 'Porcentaje de rebote',
	'General_ColumnPageviews' => 'Páginas vistas',
	'General_ColumnUniquePageviews' => 'Páginas vistas únicas ',
	'General_ColumnValuePerVisit' => 'Valor por visita',
	'General_ColumnVisitsWithConversions' => 'Visitas con conversiones',
	'General_Save' => 'Guardar',
	'General_Website' => 'Sitio web',
	'General_NoDataForGraph' => 'No hay datos para esta gráfica.',
	'General_NoDataForTagCloud' => 'No hay datos para esta nube de etiquetas.',
	'General_DisplayNormalTable' => 'Mostrar la tabla normal',
	'General_DisplayMoreData' => 'Mostrar más datos',
	'General_PiwikIsACollaborativeProjectYouCanContribute' => '%s Piwik %s es un proyecto colaborativo. %s ¡Si te gusta Piwik, puedes ayudar! Comprueba %s ¿Cómo contribuir con Piwik?%s ',
	'General_YouAreCurrentlyViewingDemoOfPiwik' => 'Estás viendo en este momento la demo de %s; ¡%sdescarga%s la versión completa! Comprueba %s',
	'General_PiwikXIsAvailablePleaseUpdateNow' => 'Piwik %s está disponible. %s ¡Por favor, actualice ahora!%s (ver %s cambios%s).',
	'General_BackToPiwik' => 'Volver a Piwik',
	'General_ShortMonth_1' => 'Ene',
	'General_ShortMonth_2' => 'Feb',
	'General_ShortMonth_3' => 'Mar',
	'General_ShortMonth_4' => 'Abr',
	'General_ShortMonth_5' => 'May',
	'General_ShortMonth_6' => 'Jun',
	'General_ShortMonth_7' => 'Jul',
	'General_ShortMonth_8' => 'Ago',
	'General_ShortMonth_9' => 'Sep',
	'General_ShortMonth_10' => 'Oct',
	'General_ShortMonth_11' => 'Nov',
	'General_ShortMonth_12' => 'Dic',
	'General_LongMonth_1' => 'Enero',
	'General_LongMonth_2' => 'Febrero',
	'General_LongMonth_3' => 'Marzo',
	'General_LongMonth_4' => 'Abril',
	'General_LongMonth_5' => 'Mayo',
	'General_LongMonth_6' => 'Junio',
	'General_LongMonth_7' => 'Julio',
	'General_LongMonth_8' => 'Agost',
	'General_LongMonth_9' => 'Septiembre',
	'General_LongMonth_10' => 'Octubre',
	'General_LongMonth_11' => 'Noviembre',
	'General_LongMonth_12' => 'Diciembre',
	'General_ShortDay_1' => 'Lun',
	'General_ShortDay_2' => 'Mar',
	'General_ShortDay_3' => 'Mié',
	'General_ShortDay_4' => 'Jue',
	'General_ShortDay_5' => 'Vie',
	'General_ShortDay_6' => 'Sáb',
	'General_ShortDay_7' => 'Dom',
	'General_LongDay_1' => 'Lunes',
	'General_LongDay_2' => 'Martes',
	'General_LongDay_3' => 'Miércoles',
	'General_LongDay_4' => 'Jueves',
	'General_LongDay_5' => 'Viernes',
	'General_LongDay_6' => 'Sábado',
	'General_LongDay_7' => 'Domingo',
	'CorePluginsAdmin_Plugins' => 'Plugins',
	'CorePluginsAdmin_PluginsManagement' => 'Administración de Plugins',
	'CorePluginsAdmin_MainDescription' => 'Los plugins extienden y amplian las funcionalidades de Piwik. Una vez que el plugin esté instalado, usted puede activarlo o desactivarlo desde aquí.',
	'CorePluginsAdmin_Plugin' => 'Plugin',
	'CorePluginsAdmin_Version' => 'Versión',
	'CorePluginsAdmin_Description' => 'Descripción',
	'CorePluginsAdmin_Status' => 'Estado',
	'CorePluginsAdmin_Action' => 'Acción',
	'CorePluginsAdmin_PluginHomepage' => 'Página del Plugin',
	'CorePluginsAdmin_Activated' => 'Activado',
	'CorePluginsAdmin_Active' => 'Activo',
	'CorePluginsAdmin_Inactive' => 'Inactivo',
	'CorePluginsAdmin_ActivatedHelp' => 'Este plugin no puede ser desactivado',
	'CorePluginsAdmin_Deactivate' => 'Desactivar',
	'CorePluginsAdmin_Activate' => 'Activar',
	'CorePluginsAdmin_MenuPlugins' => 'Plugins',
	'API_QuickDocumentation' => '<h2>Documentación rápida de la API</h2><p>Si no tiene datos para el día de hoy, primero puede <a href=\'misc/generateVisits.php\' target=_blank>generar algunos datos</a> usando el script de generación de visitas.</p><p>Puede probar los distintos formatos disponibles para cada método. ¡Es muy fácil extraer los datos que desee de Piwik!</p><p><b>Para más información échale un vistazo a la <a href=\'http://dev.piwik.org/trac/wiki/API\'>Documentación oficial de la API</a> o a la <a href=\'http://dev.piwik.org/trac/wiki/API/Reference\'>Referencia de la API</a>.</b></P><h2>Autentificación de usuario</h2><p>Si desea <b>obtener los datos en sus scripts, en un crontab, etc. </b> necesitará añadir el parámetro <code><u>&token_auth=%s</u></code> a las URLs de llamada a la API que requiere autenticación.</p><p>¡Esta token_auth es secreta como su usuario y contraseña, <b>no la comparta!</p>',
	'API_LoadedAPIs' => 'Se han cargado %s APIs con éxito',
	'CoreHome_NoPrivileges' => 'Está conectado como \'%s\' pero parece que no tiene ningún permiso configurado en Piwik.<br />Pregúntele a su administrador de Piwik para que le de el acceso \'ver\' un sitio web.',
	'CoreHome_JavascriptDisabled' => 'JavaScript debe estar activado para poder utilizar Piwik en la vista estándar.<br />Sin embargo, parece que el JavaScript está desactivado o no es compatible con su navegador.<br />Para utilizar la vista estándar, active JavaScript cambiando las opciones de su navegador, a continuación, %1sinténtelo de nuevo%2s.<br />',
	'CoreHome_TableNoData' => 'No hay datos para esta tabla.',
	'CoreHome_CategoryNoData' => 'No hay datos en esta categoría. Intenta "Incluir toda la población".',
	'CoreHome_ShowJSCode' => 'Mostrar el código JavaScript para insertar',
	'CoreHome_IncludeAllPopulation_js' => 'Incluir toda la población',
	'CoreHome_ExcludeLowPopulation_js' => 'Excluir baja población',
	'CoreHome_PageOf_js' => '%s de %s',
	'CoreHome_Loading_js' => 'Cargando...',
	'CoreHome_DayFormat' => '%longDay% %day% %longMonth% %longYear%',
	'CoreHome_PeriodDay' => 'Día',
	'CoreHome_PeriodWeek' => 'Semana',
	'CoreHome_PeriodMonth' => 'Mes',
	'CoreHome_PeriodYear' => 'Año',
	'CoreHome_PeriodDays' => 'días',
	'CoreHome_PeriodWeeks' => 'semanas',
	'CoreHome_PeriodMonths' => 'meses',
	'CoreHome_PeriodYears' => 'años',
	'CoreHome_DaySu_js' => 'Do',
	'CoreHome_DayMo_js' => 'Lu',
	'CoreHome_DayTu_js' => 'Ma',
	'CoreHome_DayWe_js' => 'Mi',
	'CoreHome_DayTh_js' => 'Ju',
	'CoreHome_DayFr_js' => 'Vi',
	'CoreHome_DaySa_js' => 'Sá',
	'CoreHome_ShortDay_1_js' => 'Dom',
	'CoreHome_ShortDay_2_js' => 'Lun',
	'CoreHome_ShortDay_3_js' => 'Mar',
	'CoreHome_ShortDay_4_js' => 'Mié',
	'CoreHome_ShortDay_5_js' => 'Juv',
	'CoreHome_ShortDay_6_js' => 'Vie',
	'CoreHome_ShortDay_7_js' => 'Sáb',
	'CoreHome_LongDay_1_js' => 'Domingo',
	'CoreHome_LongDay_2_js' => 'Lunes',
	'CoreHome_LongDay_3_js' => 'Martes',
	'CoreHome_LongDay_4_js' => 'Miércoles',
	'CoreHome_LongDay_5_js' => 'Jueves',
	'CoreHome_LongDay_6_js' => 'Viernes',
	'CoreHome_LongDay_7_js' => 'Sábado',
	'CoreHome_ShortMonth_1_js' => 'Ene',
	'CoreHome_ShortMonth_2_js' => 'Feb',
	'CoreHome_ShortMonth_3_js' => 'Mar',
	'CoreHome_ShortMonth_4_js' => 'Abr',
	'CoreHome_ShortMonth_5_js' => 'May',
	'CoreHome_ShortMonth_6_js' => 'Jun',
	'CoreHome_ShortMonth_7_js' => 'Jul',
	'CoreHome_ShortMonth_8_js' => 'Ago',
	'CoreHome_ShortMonth_9_js' => 'Sep',
	'CoreHome_ShortMonth_10_js' => 'Oct',
	'CoreHome_ShortMonth_11_js' => 'Nov',
	'CoreHome_ShortMonth_12_js' => 'Dic',
	'CoreHome_MonthJanuary_js' => 'Enero',
	'CoreHome_MonthFebruary_js' => 'Febrero',
	'CoreHome_MonthMarch_js' => 'Marzo',
	'CoreHome_MonthApril_js' => 'Abril',
	'CoreHome_MonthMay_js' => 'Mayo',
	'CoreHome_MonthJune_js' => 'Junio',
	'CoreHome_MonthJuly_js' => 'Julio',
	'CoreHome_MonthAugust_js' => 'Agosto',
	'CoreHome_MonthSeptember_js' => 'Septiembre',
	'CoreHome_MonthOctober_js' => 'Octubre',
	'CoreHome_MonthNovember_js' => 'Noviembre',
	'CoreHome_MonthDecember_js' => 'Diciembre',
	'CoreUpdater_UpdateTitle' => 'Actualización de Piwik &rsaquo;',
	'CoreUpdater_DatabaseUpgradeRequired' => 'La base de datos necesita actualizarse',
	'CoreUpdater_YourDatabaseIsOutOfDate' => 'Su base de datos de Piwik está obsoleta, y debe ser actualizada antes de poder continuar.',
	'CoreUpdater_PiwikWillBeUpgradedFromVersionXToVersionY' => 'La base de datos de Piwik será actualizada desde la versión %s a la nueva versión %s.',
	'CoreUpdater_TheFollowingPluginsWillBeUpgradedX' => 'Los siguientes plugins serán actualizados: %s.',
	'CoreUpdater_TheUpgradeProcessMayTakeAWhilePleaseBePatient' => 'El proceso de actualización de la base de datos puede llevar un tiempo, así que por favor sea paciente.',
	'CoreUpdater_UpgradePiwik' => 'Actualizar Piwik',
	'CoreUpdater_HelpMessageContent' => 'Comprueba la %s Piwik FAQ %s que explica los errores más comunes durante la actualización. %s Pregúntele a su administrador del sistema - que puede ser capaz de ayudarle con el error, que es más probable que sea en relación a su servidor o la configuración de MySQL.',
	'CoreUpdater_CriticalErrorDuringTheUpgradeProcess' => 'Error crítico durante el proceso de actualización:',
	'CoreUpdater_HelpMessageIntroductionWhenError' => 'Lo anterior es un mensaje de error del núcleo. Debe ayudarle a explicar la causa, pero si necesita más ayuda, por favor:',
	'CoreUpdater_HelpMessageIntroductionWhenWarning' => 'Actualización completada con éxito, sin embargo hubo problemas durante el proceso. Por favor, lea las descripciones anteriores para obtener más detalles. Para obtener más ayuda:',
	'CoreUpdater_UpgradeComplete' => '¡Actualización completa!',
	'CoreUpdater_WarningMessages' => 'Mensajes de advertencia:',
	'CoreUpdater_ErrorDuringPluginsUpdates' => 'Error durante la actualización del plugin:',
	'CoreUpdater_WeAutomaticallyDeactivatedTheFollowingPlugins' => 'Desactivaremos automáticamente los siguientes plugins: %s',
	'CoreUpdater_PiwikHasBeenSuccessfullyUpgraded' => '¡Piwik se ha actualizado correctamente!',
	'CoreUpdater_ContinueToPiwik' => 'Ir a Piwik',
	'CoreUpdater_UpdateAutomatically' => 'Actualización automática',
	'CoreUpdater_ThereIsNewVersionAvailableForUpdate' => 'Hay una nueva versión de Piwik disponible para actualizar',
	'CoreUpdater_YouCanUpgradeAutomaticallyOrDownloadPackage' => 'Puede actualizar automáticamente a la versión %s o descargar el paquete e instalarlo manualmente:',
	'CoreUpdater_DownloadX' => 'Descarga %s',
	'CoreUpdater_UpdateHasBeenCancelledExplanation' => 'La actualización con Un Clic de Piwik se ha cancelado. Si no puede solucionar el mensaje de error anterior, se recomienda que actualice Piwik manualmente. %s ¡Por favor, consulte la %sdocumentación de actualización%s para empezar!',
	'CoreUpdate_DownloadingUpdateFromX' => 'Descargando actualización desde %s',
	'CoreUpdate_UnpackingTheUpdate' => 'Desempaquetando la actualización',
	'CoreUpdater_VerifyingUnpackedFiles' => 'Verificando los archivos desempaquetados',
	'CoreUpdater_CreatingBackupOfConfigurationFile' => 'Creando una copia de seguridad del archivo de configuración en %s',
	'CoreUpdater_InstallingTheLatestVersion' => 'Instalando la última versión',
	'CoreUpdater_PiwikUpdatedSuccessfully' => '¡Piwik actualizado con éxito!',
	'CoreUpdater_EmptyDatabaseError' => 'La base de datos %s está vacía. Debes modificar o eliminar tu archivo de configuración de Piwik.',
	'Actions_Actions' => 'Acciones',
	'Actions_SubmenuPages' => 'Páginas',
	'Actions_SubmenuOutlinks' => 'Enlaces externos',
	'Actions_SubmenuDownloads' => 'Descargas',
	'Actions_ColumnClicks' => 'Clics',
	'Actions_ColumnUniqueClicks' => ' Clics únicos',
	'Actions_ColumnDownloads' => 'Descargas',
	'Actions_ColumnUniqueDownloads' => 'Descargas Únicas',
	'Actions_ColumnPageName' => 'Páginas',
	'Actions_ColumnClickedURL' => 'URLs cliqueadas',
	'Actions_ColumnDownloadURL' => 'URLs de descargas',
	'Dashboard_Dashboard' => 'Panel',
	'Dashboard_AddWidget' => 'Añadir un widget...',
	'Dashboard_DeleteWidgetConfirm' => '¿Está seguro de que quiere borrar este widget de su panel?',
	'Dashboard_SelectWidget' => 'Selecciona el widget para añadir en el panel',
	'Dashboard_AddPreviewedWidget_js' => 'Añade el widget previsualizado al panel',
	'Dashboard_WidgetPreview_js' => 'Previsualización del Widget',
	'Dashboard_Close_js' => 'Cerrar',
	'Dashboard_TitleWidgetInDashboard_js' => 'El Widget ya está en el panel',
	'Dashboard_TitleClickToAdd_js' => 'Clic para añadir al panel',
	'Dashboard_LoadingWidget_js' => 'Cargando widget, por favor espere...',
	'Dashboard_WidgetNotFound_js' => 'Widget no encontrado',
	'Referers_Referers' => 'Referencias',
	'Referers_SearchEngines' => 'Motores de búsqueda',
	'Referers_Keywords' => 'Palabras clave',
	'Referers_DirectEntry' => 'Entrada directa',
	'Referers_Websites' => 'Sitios web',
	'Referers_Campaigns' => 'Campañas',
	'Referers_MetricsFromRefererTypeGraphLegend' => '%1s (desde %2s)',
	'Referers_Evolution' => 'Evolución en el periodo',
	'Referers_Type' => 'Tipo de referencia',
	'Referers_ColumnRefererType' => 'Tipo de referencia',
	'Referers_ColumnSearchEngine' => 'Motores de búsqueda',
	'Referers_ColumnWebsite' => 'Sitio web',
	'Referers_ColumnWebsitePage' => 'Página web',
	'Referers_ColumnKeyword' => 'Palabras clave',
	'Referers_ColumnCampaign' => 'Campaña',
	'Referers_DetailsByRefererType' => 'Detalles por tipo de referencia',
	'Referers_TypeDirectEntries' => '%s entradas directas',
	'Referers_TypeSearchEngines' => '%s desde motores de búsqueda',
	'Referers_TypeWebsites' => '%s desde páginas webs',
	'Referers_TypeCampaigns' => '%s desde campañas',
	'Referers_Distinct' => 'Distintas referencias por tipo de referencia',
	'Referers_DistinctSearchEngines' => 'motores de búsqueda distintos',
	'Referers_DistinctKeywords' => 'palabras clave distintas',
	'Referers_DistinctCampaigns' => 'campañas distintas',
	'Referers_DistinctWebsites' => 'páginas web distintas',
	'Referers_UsingNDistinctUrls' => ' (usando %2s URLs diferentes)',
	'Referers_SubmenuEvolution' => 'Evolución',
	'Referers_SubmenuSearchEngines' => 'Motores de búsqueda y palabras clave',
	'Referers_SubmenuWebsites' => 'Páginas web',
	'Referers_SubmenuCampaigns' => 'Campañas',
	'Referers_WidgetKeywords' => 'Lista de Palabras clave',
	'Referers_WidgetCampaigns' => 'Lista de Campañas',
	'Referers_WidgetExternalWebsites' => 'Lista de páginas web externas',
	'Referers_WidgetSearchEngines' => 'Mejores motores de búsqueda',
	'Referers_WidgetOverview' => 'General',
	'UserSettings_VisitorSettings' => 'Configuración de visitantes',
	'UserSettings_BrowserFamilies' => 'Familia de Navegadores',
	'UserSettings_Browsers' => 'Navegadores',
	'UserSettings_Plugins' => 'Plugins',
	'UserSettings_Configurations' => 'Configuración',
	'UserSettings_OperatingSystems' => 'Sistemas operativos',
	'UserSettings_Resolutions' => 'Resoluciones',
	'UserSettings_WideScreen' => 'Pantalla panorámica',
	'UserSettings_ColumnBrowserFamily' => 'Buscadores por familia',
	'UserSettings_ColumnBrowser' => 'Navegador',
	'UserSettings_ColumnPlugin' => 'Plugin',
	'UserSettings_ColumnConfiguration' => 'Configuración',
	'UserSettings_ColumnOperatingSystem' => 'Sistemas operativos',
	'UserSettings_ColumnResolution' => 'Resoluciones',
	'UserSettings_ColumnTypeOfScreen' => 'Tipo de pantalla',
	'UserSettings_WidgetResolutions' => 'Resoluciones de pantalla',
	'UserSettings_WidgetBrowsers' => 'Navegadores de los visitantes',
	'UserSettings_WidgetPlugins' => 'Lista de Plugins',
	'UserSettings_WidgetWidescreen' => 'Normal / Panorámica',
	'UserSettings_WidgetBrowserFamilies' => 'Buscadores por familia',
	'UserSettings_WidgetOperatingSystems' => 'Sistemas operativos',
	'UserSettings_WidgetGlobalVisitors' => 'Configuración global de visitantes',
	'UserSettings_SubmenuSettings' => 'Ajustes',
	'UserCountry_Country' => 'País',
	'UserCountry_Continent' => 'Continente',
	'UserCountry_DistinctCountries' => '%s países distintos',
	'UserCountry_SubmenuLocations' => 'Localizaciones',
	'UserCountry_WidgetContinents' => 'Continentes de los visitantes',
	'UserCountry_WidgetCountries' => 'Países de los visitantes',
	'UserCountry_country_ac' => 'Isla Ascensión',
	'UserCountry_country_ad' => 'Andorra',
	'UserCountry_country_ae' => 'Emiratos Árabes Unidos',
	'UserCountry_country_af' => 'Afganistán',
	'UserCountry_country_ag' => 'Antigua y Barbuda',
	'UserCountry_country_ai' => 'Anguila',
	'UserCountry_country_al' => 'Albania',
	'UserCountry_country_am' => 'Armenia',
	'UserCountry_country_an' => 'Antillas Neerlandesas',
	'UserCountry_country_ao' => 'Angola',
	'UserCountry_country_aq' => 'Antártida',
	'UserCountry_country_ar' => 'Argentina',
	'UserCountry_country_as' => 'América Samoa',
	'UserCountry_country_at' => 'Austria',
	'UserCountry_country_au' => 'Australia',
	'UserCountry_country_aw' => 'Aruba',
	'UserCountry_country_ax' => 'Islas de Åland',
	'UserCountry_country_az' => 'Azerbaiyán',
	'UserCountry_country_ba' => 'Bosnia Herzegovina',
	'UserCountry_country_bb' => 'Barbados',
	'UserCountry_country_bd' => 'Bangladesh',
	'UserCountry_country_be' => 'Bélgica',
	'UserCountry_country_bf' => 'Burkina Faso',
	'UserCountry_country_bg' => 'Bulgaria',
	'UserCountry_country_bh' => 'Bahrein',
	'UserCountry_country_bi' => 'Burundi',
	'UserCountry_country_bj' => 'Benin',
	'UserCountry_country_bl' => 'San Bartolomé',
	'UserCountry_country_bm' => 'Bermudas',
	'UserCountry_country_bn' => 'Bruneo',
	'UserCountry_country_bo' => 'Bolivia',
	'UserCountry_country_br' => 'Brasil',
	'UserCountry_country_bs' => 'Bahamas',
	'UserCountry_country_bt' => 'Bután',
	'UserCountry_country_bu' => 'Birmania',
	'UserCountry_country_bv' => 'Isla Bouvet',
	'UserCountry_country_bw' => 'Botsuana',
	'UserCountry_country_by' => 'Bielorrusia',
	'UserCountry_country_bz' => 'Belice',
	'UserCountry_country_ca' => 'Canadá',
	'UserCountry_country_cc' => 'Islas Cocos',
	'UserCountry_country_cd' => 'Congo, La República Democrática',
	'UserCountry_country_cf' => 'República Centroafricana',
	'UserCountry_country_cg' => 'Congo',
	'UserCountry_country_ch' => 'Suiza',
	'UserCountry_country_ci' => 'Costa de Marfil',
	'UserCountry_country_ck' => 'Islas Cook',
	'UserCountry_country_cl' => 'Chile',
	'UserCountry_country_cm' => 'Camerún',
	'UserCountry_country_cn' => 'China',
	'UserCountry_country_co' => 'Colombia',
	'UserCountry_country_cp' => 'Isla de la Pasión',
	'UserCountry_country_cr' => 'Costa Rica',
	'UserCountry_country_cs' => 'Serbia Montenegro',
	'UserCountry_country_cu' => 'Cuba',
	'UserCountry_country_cv' => 'Cabo verde',
	'UserCountry_country_cx' => 'Islas Christmas',
	'UserCountry_country_cy' => 'Chipre',
	'UserCountry_country_cz' => 'República Checa',
	'UserCountry_country_de' => 'Alemania',
	'UserCountry_country_dg' => 'Diego Garcia',
	'UserCountry_country_dj' => 'Yibuti',
	'UserCountry_country_dk' => 'Dinamarca',
	'UserCountry_country_dm' => 'Dominica',
	'UserCountry_country_do' => 'República Dominicana',
	'UserCountry_country_dz' => 'Argelia',
	'UserCountry_country_ea' => 'Ceuta, Melilla',
	'UserCountry_country_ec' => 'Ecuador',
	'UserCountry_country_ee' => 'Estonia',
	'UserCountry_country_eg' => 'Egipto',
	'UserCountry_country_eh' => 'Sáhara Occidental',
	'UserCountry_country_er' => 'Eritrea',
	'UserCountry_country_es' => 'España',
	'UserCountry_country_et' => 'Etiopía',
	'UserCountry_country_eu' => 'Unión Europea',
	'UserCountry_country_fi' => 'Finlandia',
	'UserCountry_country_fj' => 'Fiji',
	'UserCountry_country_fk' => 'Islas Malvinas',
	'UserCountry_country_fm' => 'Micronesia, Estados Federados',
	'UserCountry_country_fo' => 'Islas Feroe',
	'UserCountry_country_fr' => 'Francia',
	'UserCountry_country_fx' => 'Francia, Metropolitana',
	'UserCountry_country_ga' => 'Gabón',
	'UserCountry_country_gb' => 'Gran Bretaña',
	'UserCountry_country_gd' => 'Granada',
	'UserCountry_country_ge' => 'Georgia',
	'UserCountry_country_gf' => 'Guayana Francesa',
	'UserCountry_country_gg' => 'Guernsey',
	'UserCountry_country_gh' => 'Ghana',
	'UserCountry_country_gi' => 'Gibraltar',
	'UserCountry_country_gl' => 'Groenlandia',
	'UserCountry_country_gm' => 'Gambia',
	'UserCountry_country_gn' => 'Guinea',
	'UserCountry_country_gp' => 'Guadaloupe',
	'UserCountry_country_gq' => 'Guinea Ecuatorial',
	'UserCountry_country_gr' => 'Greece',
	'UserCountry_country_gs' => 'Islas Georgia del Sur y  Sandwich del Sur',
	'UserCountry_country_gt' => 'Guatemala',
	'UserCountry_country_gu' => 'Guam',
	'UserCountry_country_gw' => 'Guinea-Bissau',
	'UserCountry_country_gy' => 'Guayana',
	'UserCountry_country_hk' => 'Hong Kong',
	'UserCountry_country_hm' => 'Islas Heard y McDonald',
	'UserCountry_country_hn' => 'Honduras',
	'UserCountry_country_hr' => 'Croacia',
	'UserCountry_country_ht' => 'Haiti',
	'UserCountry_country_hu' => 'Hungría',
	'UserCountry_country_ic' => 'Islas Canarias',
	'UserCountry_country_id' => 'Indonesia',
	'UserCountry_country_ie' => 'Irlanda',
	'UserCountry_country_il' => 'Israel',
	'UserCountry_country_im' => 'Isla de Man',
	'UserCountry_country_in' => 'India',
	'UserCountry_country_io' => 'Territorio Británico del Océano Índico',
	'UserCountry_country_iq' => 'Iraq',
	'UserCountry_country_ir' => 'Irán, República Islámica',
	'UserCountry_country_is' => 'Islandia',
	'UserCountry_country_it' => 'Italia',
	'UserCountry_country_je' => 'Jersey',
	'UserCountry_country_jm' => 'Jamaica',
	'UserCountry_country_jo' => 'Jordania',
	'UserCountry_country_jp' => 'Japón',
	'UserCountry_country_ke' => 'Kenia',
	'UserCountry_country_kg' => 'Kirguistán',
	'UserCountry_country_kh' => 'Camboya',
	'UserCountry_country_ki' => 'Kiribati',
	'UserCountry_country_km' => 'Comores',
	'UserCountry_country_kn' => 'San Cristóbal y Nieves',
	'UserCountry_country_kp' => 'Corea, República Popular Democrática de Corea',
	'UserCountry_country_kr' => 'Corea, República de Corea',
	'UserCountry_country_kw' => 'Kuwait',
	'UserCountry_country_ky' => 'Islas Caimán',
	'UserCountry_country_kz' => 'Kazajstán',
	'UserCountry_country_la' => 'Laos',
	'UserCountry_country_lb' => 'Líbano',
	'UserCountry_country_lc' => 'Santa Lucía',
	'UserCountry_country_li' => 'Liechtenstein',
	'UserCountry_country_lk' => 'Sri Lanka',
	'UserCountry_country_lr' => 'Liberia',
	'UserCountry_country_ls' => 'Lesotho',
	'UserCountry_country_lt' => 'Lituania',
	'UserCountry_country_lu' => 'Luxemburgo',
	'UserCountry_country_lv' => 'Letonia',
	'UserCountry_country_ly' => 'Libia',
	'UserCountry_country_ma' => 'Marruecos',
	'UserCountry_country_mc' => 'Mónaco',
	'UserCountry_country_md' => 'Moldova, República de Moldavia',
	'UserCountry_country_me' => 'Montenegro',
	'UserCountry_country_mf' => 'San Martin',
	'UserCountry_country_mg' => 'Madagascar',
	'UserCountry_country_mh' => 'Islas Marshall',
	'UserCountry_country_mk' => 'Macedonia',
	'UserCountry_country_ml' => 'Mali',
	'UserCountry_country_mm' => 'Myanmar',
	'UserCountry_country_mn' => 'Mongolia',
	'UserCountry_country_mo' => 'Macao',
	'UserCountry_country_mp' => 'Islas Marianas del Norte',
	'UserCountry_country_mq' => 'Martinica',
	'UserCountry_country_mr' => 'Mauritania',
	'UserCountry_country_ms' => 'Montserrat',
	'UserCountry_country_mt' => 'Malta',
	'UserCountry_country_mu' => 'Mauricio',
	'UserCountry_country_mv' => 'Maldivas',
	'UserCountry_country_mw' => 'Malawi',
	'UserCountry_country_mx' => 'México',
	'UserCountry_country_my' => 'Malasia',
	'UserCountry_country_mz' => 'Mozambique',
	'UserCountry_country_na' => 'Namibia',
	'UserCountry_country_nc' => 'Nueva Caledoniaa',
	'UserCountry_country_ne' => 'Niger',
	'UserCountry_country_nf' => 'Isla Norfolk',
	'UserCountry_country_ng' => 'Nigeria',
	'UserCountry_country_ni' => 'Nicaragua',
	'UserCountry_country_nl' => 'Países bajos',
	'UserCountry_country_no' => 'Noruega',
	'UserCountry_country_np' => 'Nepal',
	'UserCountry_country_nr' => 'Nauru',
	'UserCountry_country_nt' => 'Zona Neutral',
	'UserCountry_country_nu' => 'Niue',
	'UserCountry_country_nz' => 'Nueva Zelanda',
	'UserCountry_country_om' => 'Omán',
	'UserCountry_country_pa' => 'Panamá',
	'UserCountry_country_pe' => 'Perú',
	'UserCountry_country_pf' => 'Polinesia Francesa',
	'UserCountry_country_pg' => 'Papua Nueva Guinea',
	'UserCountry_country_ph' => 'Filipinas',
	'UserCountry_country_pk' => 'Pakistán',
	'UserCountry_country_pl' => 'Polonia',
	'UserCountry_country_pm' => 'San Pedro y Miquelón',
	'UserCountry_country_pn' => 'Pitcairn',
	'UserCountry_country_pr' => 'Puerto Rico',
	'UserCountry_country_ps' => 'Territorio Palestino',
	'UserCountry_country_pt' => 'Portugal',
	'UserCountry_country_pw' => 'Palau',
	'UserCountry_country_py' => 'Paraguay',
	'UserCountry_country_qa' => 'Qatar',
	'UserCountry_country_re' => 'Isla Reunión',
	'UserCountry_country_ro' => 'Rumanía',
	'UserCountry_country_ru' => 'Rusia',
	'UserCountry_country_rs' => 'Serbia',
	'UserCountry_country_rw' => 'Ruanda',
	'UserCountry_country_sa' => 'Arabia Saudí',
	'UserCountry_country_sb' => 'Islas Salomón',
	'UserCountry_country_sc' => 'Seychelles',
	'UserCountry_country_sd' => 'Sudán',
	'UserCountry_country_se' => 'Suiza',
	'UserCountry_country_sf' => 'Finlandia',
	'UserCountry_country_sg' => 'Singaur',
	'UserCountry_country_sh' => 'Santa Helena',
	'UserCountry_country_si' => 'Eslovenia',
	'UserCountry_country_sj' => 'Svalbard',
	'UserCountry_country_sk' => 'Eslovaquia',
	'UserCountry_country_sl' => 'Sierra Leona',
	'UserCountry_country_sm' => 'San Marino',
	'UserCountry_country_sn' => 'Senegal',
	'UserCountry_country_so' => 'Somalia',
	'UserCountry_country_sr' => 'Surinam',
	'UserCountry_country_st' => 'Santo Tomé y Príncipe',
	'UserCountry_country_su' => 'Antigua U.S.S.R.',
	'UserCountry_country_sv' => 'El Salvador',
	'UserCountry_country_sy' => 'República Árabe Siria',
	'UserCountry_country_sz' => 'Suazilandia',
	'UserCountry_country_ta' => 'Tristán da Cunha',
	'UserCountry_country_tc' => 'Islas Turcas y Caicos',
	'UserCountry_country_td' => 'Chad',
	'UserCountry_country_tf' => 'Territorios Franceses del Sur',
	'UserCountry_country_tg' => 'Togo',
	'UserCountry_country_th' => 'Tailandia',
	'UserCountry_country_tj' => 'Tayikistán',
	'UserCountry_country_tk' => 'Tokelau',
	'UserCountry_country_tl' => 'Timor Oriental',
	'UserCountry_country_tm' => 'Turkmenistán',
	'UserCountry_country_tn' => 'Túnez',
	'UserCountry_country_to' => 'Tonga',
	'UserCountry_country_tp' => 'Timor Occidental',
	'UserCountry_country_tr' => 'Turquía',
	'UserCountry_country_tt' => 'Trinidad y Tobago',
	'UserCountry_country_tv' => 'Tuvalu',
	'UserCountry_country_tw' => 'Taiwán',
	'UserCountry_country_tz' => 'Tanzania, República Unida de Tanzania',
	'UserCountry_country_ua' => 'Ucrania',
	'UserCountry_country_ug' => 'Uganda',
	'UserCountry_country_uk' => 'Gran Bretaña',
	'UserCountry_country_um' => 'Islas Menores de los Estados Unidos',
	'UserCountry_country_us' => 'Estados Unidos',
	'UserCountry_country_uy' => 'Uruguay',
	'UserCountry_country_uz' => 'Uzbekistán',
	'UserCountry_country_va' => 'Ciudad del Vaticano',
	'UserCountry_country_vc' => 'San Vicente y las Granadinas',
	'UserCountry_country_ve' => 'Venezuela',
	'UserCountry_country_vg' => 'Islas Vírgenes Británicas',
	'UserCountry_country_vi' => 'Islas Vírgenes, EE.UU.',
	'UserCountry_country_vn' => 'Vietnam',
	'UserCountry_country_vu' => 'Vanuatu',
	'UserCountry_country_wf' => 'Wallis y Futuna',
	'UserCountry_country_ws' => 'Samoa',
	'UserCountry_country_ye' => 'Yemen',
	'UserCountry_country_yt' => 'Mayotte',
	'UserCountry_country_yu' => 'Yugoslavia',
	'UserCountry_country_za' => 'Sudáfrica',
	'UserCountry_country_zm' => 'Zambia',
	'UserCountry_country_zr' => 'Zaire',
	'UserCountry_country_zw' => 'Zimbabue',
	'UserCountry_continent_eur' => 'Europa',
	'UserCountry_continent_afr' => 'África',
	'UserCountry_continent_asi' => 'Asia',
	'UserCountry_continent_ams' => 'América del Sur y Central',
	'UserCountry_continent_amn' => 'América del Norte',
	'UserCountry_continent_oce' => 'Oceanía',
	'VisitsSummary_NbVisits' => '%s visitas',
	'VisitsSummary_NbUniqueVisitors' => '%s visitas únicas',
	'VisitsSummary_NbActions' => '%s acciones (páginas vistas)',
	'VisitsSummary_TotalTime' => '%s tiempo total empleado por los visitantes',
	'VisitsSummary_MaxNbActions' => '%s acciones máximas en una visita',
	'VisitsSummary_NbVisitsBounced' => '%s de visitas que han vuelto (abandonaron el sitio después de una página)',
	'VisitsSummary_EvolutionOverLastPeriods' => 'Evolución en los últimos %s',
	'VisitsSummary_Report' => 'Informe',
	'VisitsSummary_GenerateTime' => '%s segundos para generar la página',
	'VisitsSummary_GenerateQueries' => '%s consultas ejecutadas',
	'VisitsSummary_WidgetLastVisits' => 'Gráfica de las últimas visitas',
	'VisitsSummary_WidgetVisits' => 'Visión general de visitas',
	'VisitsSummary_WidgetLastVisitors' => 'Gráfica de últimos visitantes únicos',
	'VisitsSummary_WidgetOverviewGraph' => 'Visión general con gráfica',
	'VisitsSummary_SubmenuOverview' => 'Visión general',
	'VisitFrequency_Evolution' => 'Evolución en el periodo',
	'VisitFrequency_ColumnReturningVisits' => 'Visitante que ha vuelto',
	'VisitFrequency_ColumnActionsByReturningVisits' => 'Acciones por un visitante que ha vuelto',
	'VisitFrequency_ColumnMaximumActionsByAReturningVisit' => 'acciones máximas por un visitante que ha vuelto',
	'VisitFrequency_ColumnTotalTimeSpentByReturningVisits' => 'Tiempo total empleado por un visitante que ha vuelto (en segundos)',
	'VisitFrequency_ColumnBounceRateForReturningVisits' => 'Porcentaje de rebote por un visitante que ha vuelto',
	'VisitFrequency_ReturnVisits' => '%s visitantes que han vuelto',
	'VisitFrequency_ReturnActions' => '%s acciones realizadas por los visitantes que han vuelto',
	'VisitFrequency_ReturnMaxActions' => '%s acciones máximas por un visitante que ha vuelto',
	'VisitFrequency_ReturnTotalTime' => '%s tiempo total empleado por los visitantes que han vuelto',
	'VisitFrequency_ReturnBounceRate' => '%s rebotes visitas que han vuelto (abandonaron el sitio después de una página)',
	'VisitFrequency_WidgetOverview' => 'Vista general de frecuencia',
	'VisitFrequency_WidgetGraphReturning' => 'Gráfica de visitantes que han vuelto',
	'VisitFrequency_SubmenuFrequency' => 'Frecuencia',
	'VisitTime_LocalTime' => 'Visitas por hora local',
	'VisitTime_ServerTime' => 'Visitas por hora del servidor',
	'VisitTime_ColumnServerTime' => 'Hora del servidor',
	'VisitTime_ColumnLocalTime' => 'Hora local',
	'VisitTime_WidgetLocalTime' => 'Visitas por hora local',
	'VisitTime_WidgetServerTime' => 'Visitas por hora del servidor',
	'VisitTime_SubmenuTimes' => 'Tiempos',
	'VisitTime_NHour' => '%sh',
	'VisitorInterest_VisitsPerDuration' => 'Visitas por duración de visita',
	'VisitorInterest_VisitsPerNbOfPages' => 'Visitas por número de páginas',
	'VisitorInterest_ColumnVisitDuration' => 'Duración de las visitas',
	'VisitorInterest_ColumnPagesPerVisit' => 'Páginas por visita',
	'VisitorInterest_WidgetLengths' => 'Duración de las visitas',
	'VisitorInterest_WidgetPages' => 'Páginas por visita',
	'VisitorInterest_SubmenuFrequencyLoyalty' => 'Frecuencia y Fidelidad',
	'VisitorInterest_PlusXMin' => '%s min',
	'VisitorInterest_BetweenXYMinutes' => '%1s-%1s min',
	'VisitorInterest_OnePage' => '1 página',
	'VisitorInterest_NPages' => '%s páginas',
	'VisitorInterest_BetweenXYSeconds' => '%1s-%2ss',
	'Login_LoginPasswordNotCorrect' => 'Usuario y contraseña incorrectos',
	'Login_Login' => 'Usuario',
	'Login_Password' => 'Contraseña',
	'Login_LoginOrEmail' => 'Usuario o E-mail',
	'Login_LogIn' => 'Conectar',
	'Login_Logout' => 'Desconectar',
	'Login_LostYourPassword' => '¿Olvidó la contraseña?',
	'Login_RemindPassword' => 'Recordar Contraseña',
	'Login_PasswordReminder' => 'Por favor, introduzca su nombre de usuario o dirección de email. Recibirá una nueva contraseña por email',
	'Login_InvalidUsernameEmail' => 'Nombre de usuario y/o email incorrectos',
	'Login_MailTopicPasswordRecovery' => 'Recuperar contraseña',
	'Login_MailPasswordRecoveryBody' => 'Hola %1s, \n\n Tu nueva contraseña es: %2s \n\n Puedes conectarte ahora en: %3s',
	'Login_PasswordSent' => 'La contraseña acaba de ser enviada. Comprueba tu email.',
	'Login_ContactAdmin' => 'Posible razón: su hosting puede tener deshabilitado la función mail(). <br />Por favor contacte con su administrador de Piwik.',
	'UsersManager_UsersManagement' => 'Administración de Usuarios',
	'UsersManager_UsersManagementMainDescription' => 'Cree nuevos usuarios o actualice los actuales. Luego puede configurar sus permisos.',
	'UsersManager_ManageAccess' => 'Administrar el Acceso',
	'UsersManager_MainDescription' => 'Decida que usuarios de Piwik tienen acceso a sus sitios web. También puede configurar los permisos en todos los sitios a la vez.',
	'UsersManager_Sites' => 'Sitios',
	'UsersManager_AllWebsites' => 'Todos los sitios web',
	'UsersManager_ApplyToAllWebsites' => 'Aplicar a todos los sitios web',
	'UsersManager_User' => 'Usuario',
	'UsersManager_PrivNone' => 'Sin acceso',
	'UsersManager_PrivView' => 'Ver',
	'UsersManager_PrivAdmin' => 'Admin',
	'UsersManager_ChangeAllConfirm' => '¿Está seguro que quiere cambiar \'%s\' permisos en todas las páginas web?',
	'UsersManager_Login' => 'Usuario',
	'UsersManager_Password' => 'Contraseña',
	'UsersManager_Email' => 'Email',
	'UsersManager_Alias' => 'Alias',
	'UsersManager_Edit' => 'Editar',
	'UsersManager_AddUser' => 'Añadir un nuevo usuario',
	'UsersManager_MenuUsers' => 'Usuarios',
	'UsersManager_DeleteConfirm_js' => '¿Está seguro que desea eliminar al usuario %s?',
	'UsersManager_ExceptionLoginExists' => 'El usuario \'%s\' ya existe.',
	'UsersManager_ExceptionEmailExists' => 'Ya existe un usuario con el email \'%s\'.',
	'UsersManager_ExceptionInvalidLoginFormat' => 'El nombre de usuario debe ser entre %s y %s caracteres de largo y contener solo letras, números o los caracteres \'_\' o \'-\' o \'.\'',
	'UsersManager_ExceptionInvalidPassword' => 'La longitud de la contraseña debe tener entre 6 y 26 caracteres.',
	'UsersManager_ExceptionInvalidEmail' => 'El email no tiene un formato válido.',
	'UsersManager_ExceptionDeleteDoesNotExist' => 'El usuario \'%s\' no existe, por lo tanto, no puede ser borrado.',
	'UsersManager_ExceptionAdminAnonymous' => 'No puede concederle el acceso de \'administrador\' a un usuario \'anónimo\'.',
	'UsersManager_ExceptionEditAnonymous' => 'El usuario anónimo no puede ser borrado o editado. Piwik lo utiliza para definir que usuario que no se ha conectado todavía. Por ejemplo, puede hacer públicas sus estadísticas mediante el acceso \'ver\' al usuario \'anónimo\'.',
	'UsersManager_ExceptionSuperUser' => 'El usuario requerido es un Super Usuario y no puede ser consultado, editado o borrado a través de la API. Usted puede editar manualmente el Super Usuario en su archivo de configuración de Piwik.',
	'UsersManager_ExceptionUserDoesNotExist' => 'El usuario \'%s\' no existe.',
	'UsersManager_ExceptionAccessValues' => 'El parámetro debe tener acceso a uno de los siguientes valores: [ %s ]',
	'SitesManager_Sites' => 'Sitios',
	'SitesManager_WebsitesManagement' => 'Adminitración de Sitios',
	'SitesManager_MainDescription' => '¡Su informe de Análisis Web necesita Sitios Web! Añada, actualice, borre Sitios Web, y muestre el código JavaScript para insertar en sus páginas.',
	'SitesManager_JsTrackingTag' => 'Código de seguimiento JavaScript',
	'SitesManager_JsTrackingTagHelp' => 'Aquí está el código de seguimiento JavaScript para incluir en todas sus páginas',
	'SitesManager_ShowTrackingTag' => 'mostrar código de seguimiento',
	'SitesManager_NoWebsites' => 'Usted no tiene ningún sitio web que administrar.',
	'SitesManager_AddSite' => 'Añadir un nuevo Sitio',
	'SitesManager_Id' => 'Id',
	'SitesManager_Name' => 'Nombre',
	'SitesManager_Urls' => 'URLs',
	'SitesManager_MenuSites' => 'Sitios',
	'SitesManager_DeleteConfirm_js' => '¿Está seguro de querer borrar el sitio %s?',
	'SitesManager_ExceptionDeleteSite' => 'No es posible borrar este sitio ya que es el único que hay registrado. Primero añada un nuevo sitio, luego borre este.',
	'SitesManager_ExceptionNoUrl' => 'Debe especificar al menos una URL para su sitio.',
	'SitesManager_ExceptionEmptyName' => 'El nombre del sitio no puede estar vacío.',
	'SitesManager_ExceptionInvalidUrl' => 'La URL \'%s\' no es válida.',
	'Installation_Installation' => 'Instalación',
	'Installation_InstallationStatus' => 'Estado de la instalación',
	'Installation_PercentDone' => '%s %% Hecho',
	'Installation_NoConfigFound' => 'El archivo de configuración de Piwik no se ha encontrado y está intentando acceder a una página de Piwik.<br /><b>&nbsp;&nbsp;&raquo; Puede <a href=\'index.php\'>instalar Piwik ahora</a></b><br /><small>¡Si ha instalado Piwik antes y tiene algunas tablas en su BD, no se preocupe, usted puede reutilizar las mismas tablas y mantener sus datos existentes!</small>',
	'Installation_MysqlSetup' => 'Configuración de base de datos MySQL',
	'Installation_MysqlErrorConnect' => 'Error al intentar conectarse a la base de datos MySQL',
	'Installation_JsTag' => 'Etiqueta JavaScript',
	'Installation_JsTagHelp' => '<p>Para contar todos los visitantes, debe insertar el código JavaScript en todas sus páginas.</p><p>Sus páginas no tienen que ser hechas con PHP, Piwik trabajará sobre todo tipo de páginas (si es HTML, ASP, Perl o cualquier otro lenguaje).</p><p>Aquí está el código que debes introducir: (copia y pega en todas tus páginas) </p>',
	'Installation_Congratulations' => 'Enhorabuena',
	'Installation_CongratulationsHelp' => '<p>¡Enhorabuena! La instalación de Piwik está completada.</p><p>¡Asegúrese de que el código JavaScript está introducido en sus páginas, y espere a sus primeros visitantes!</p>',
	'Installation_ContinueToPiwik' => 'Ir a Piwik',
	'Installation_SetupWebsite' => 'Configurar una página web',
	'Installation_SetupWebsiteError' => 'Se ha producido un error al añadir el sitio web',
	'Installation_GeneralSetup' => 'Configuración general',
	'Installation_GeneralSetupSuccess' => 'Configuración general realizada con éxito',
	'Installation_SuperUserLogin' => 'Nombre de super usuario',
	'Installation_Password' => 'Contraseña',
	'Installation_PasswordRepeat' => 'contraseña (repetir)',
	'Installation_Email' => 'email',
	'Installation_SecurityNewsletter' => 'envíeme un email con las principales actualizaciones y alertas de seguridad de Piwik',
	'Installation_CommunityNewsletter' => 'envíeme un email con las actualizaciones de la comunidad (nuevos plugins, nuevas características, etc.)',
	'Installation_PasswordDoNotMatch' => 'las contraseñas no coinciden',
	'Installation_SubmitGo' => '¡Ir!',
	'Installation_Requirements' => 'Requisitos de Piwik',
	'Installation_Optional' => 'Opcional',
	'Installation_Legend' => 'Leyenda',
	'Installation_SystemCheck' => 'Comprobación del sistema',
	'Installation_SystemCheckPhp' => 'Versión PHP',
	'Installation_SystemCheckExtensions' => 'Extensiones requeridas',
	'Installation_SystemCheckPdoHelp' => 'Necesitas habilitar la extensión PDO en tu archivo php.ini.',
	'Installation_SystemCheckPdoMysqlHelp' => 'Necesitas habilitar la extensión PDO_MYSQL en tu archivo php.ini.',
	'Installation_SystemCheckSplHelp' => 'Necesitas configurar y reconstruir PHP con la Librería Estándar de PHP habilitada (por defecto).',
	'Installation_SystemCheckZlibHelp' => 'Necesitas configurar y reconstruir PHP con el soporte zlib habilitado, --with-zlib.',
	'Installation_SystemCheckWriteDirs' => 'Directorios con acceso de escritura',
	'Installation_SystemCheckWriteDirsHelp' => 'Para arreglar este error en su sistema Linux, intente tecleando los siguientes comandos',
	'Installation_SystemCheckMemoryLimit' => 'Límite de memoria',
	'Installation_SystemCheckMemoryLimitHelp' => 'On a high traffic website, the archiving process may require more memory than currently allowed.<br />See the directive memory_limit in your php.ini file if necessary.',
	'Installation_SystemCheckGD' => 'GD &gt; 2.x (gráficas)',
	'Installation_SystemCheckGDHelp' => 'Las "sparklines" (gráficas pequeñas) no funcionarán.',
	'Installation_SystemCheckFunctions' => 'Funciones requeridas',
	'Installation_SystemCheckTimeLimitHelp' => 'En un sitio web con un tráfico elevado, la ejecución del proceso de archivado puede requerir más tiempo del permitido.<br />Mire la directiva max_execution_time en su archivo php.ini si es necesario',
	'Installation_SystemCheckMailHelp' => 'Los mensajes de Feedback y Recuperar Contraseña no se enviarán sin mail().',
	'Installation_SystemCheckError' => 'Se ha producido un error - debe ser arreglado antes de continuar',
	'Installation_SystemCheckWarning' => 'Piwik funcionará normalmente, pero algunas características pueden faltar',
	'Installation_Tables' => 'Creando las tablas',
	'Installation_TablesWithSameNamesFound' => 'Algunas %s tablas en su base de datos %s tienen el mismo nombre como las tablas que Piwik está intentando crear.',
	'Installation_TablesFound' => 'Las siguientes tablas se han encontrado en la base de datos',
	'Installation_TablesWarningHelp' => 'O bien optar por la reutilización de las tablas de bases de datos existentes o seleccionar una instalación limpia para borrar todos los datos existentes en la base de datos.',
	'Installation_TablesReuse' => 'Reutilizar las tablas ya existentes',
	'Installation_TablesDelete' => 'Borrar las tablas detectadas',
	'Installation_TablesDeletedSuccess' => 'Tablas existentes de Piwik borradas con éxito',
	'Installation_TablesCreatedSuccess' => '¡Tablas creadas con éxito!',
	'Installation_DatabaseCreatedSuccess' => '¡Base de datos %s creada con éxito!',
	'Installation_GoBackAndDefinePrefix' => 'Vuelve atrás y define un Prefijo para las Tablas de Piwik',
	'Installation_ConfirmDeleteExistingTables' => '¿Está seguro de que desea borrar las tablas: %s de su base de datos? ADVERTENCIA: ¡LOS DATOS DE ESTAS TABLAS NO SE PUEDEN RECUPERAR!',
	'Installation_Welcome' => '¡Bienvenido!',
	'Installation_WelcomeHelp' => '<p>Piwik es un software de análisis web de código abierto que facilita el obtener la información que desea de sus visitantes.</p><p>Este proceso se divide en %s sencillos pasos que le llevarán en torno a 5 minutos.</p>',
	'Installation_ErrorInvalidState' => 'Error: parece que trata de saltar un paso del proceso de instalación, o sus cookies están desactivadas, o el archivo de configuración de Piwik ya está creado. %sAsegúrese de que las cookies están activadas%s  y vuelva %s a la primera página de la instalación %s.',
	'Provider_WidgetProviders' => 'Proveedores',
	'Provider_ColumnProvider' => 'Proveedor',
	'Provider_SubmenuLocationsProvider' => 'Localizaciones y proveedores',
	'Goals_ColumnConversions' => 'Conversiones',
	'Goals_ColumnConversionRate' => 'Porcentaje de conversiones',
	'Goals_ColumnRevenue' => 'Ingresos',
	'DBStats_DatabaseUsage' => 'Uso de la base de datos',
	'DBStats_MainDescription' => 'Piwik está almacenando todos sus datos de análisis web en la base de datos MySQL. Actualmente, las tablas de Piwik están usando %s.',
	'DBStats_Table' => 'Tabla',
	'DBStats_RowNumber' => 'Número de fila',
	'DBStats_DataSize' => 'Tamaño de los datos',
	'DBStats_IndexSize' => 'Índice de tamaño',
	'DBStats_TotalSize' => 'Tamaño total',
	'TranslationsAdmin_MenuTranslations' => 'Traducciones',
	'TranslationsAdmin_MenuLanguages' => 'Idiomas',
	'TranslationsAdmin_Plugin' => 'Plugin',
	'TranslationsAdmin_Definition' => 'Definición',
	'TranslationsAdmin_DefaultString' => 'Cadena por defecto (Español)',
	'TranslationsAdmin_TranslationString' => 'Cadena de traducción (idioma actual: %s)',
	'TranslationsAdmin_Translations' => 'Traducciones',
	'TranslationsAdmin_FixPermissions' => 'Por favor arregle los permisos de los archivos de sistema',
	'TranslationsAdmin_AvailableLanguages' => 'Idiomas disponibles',
	'TranslationsAdmin_AddLanguage' => 'Añadir un idioma',
	'TranslationsAdmin_LanguageCode' => 'Código de idioma',
	'TranslationsAdmin_Export' => 'Exportar idioma',
	'TranslationsAdmin_Import' => 'Importar idioma',
);
